==> breizhcrops-0.0.2.9-py3-none-any.whl: breizhcrops/datasets/urls.py <==
RAW_CSV_URL = {
    2017: {
        "L1C": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh01.zip",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh02.zip",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh03.zip",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh04.zip",
        },
        "L2A": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh01.zip",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh02.zip",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh03.zip",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh04.zip",

        }
    },
    2018: {
        "L1C": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh01.zip",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh02.zip",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh03.zip",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh04.zip",
        }
    }
}

INDEX_FILE_URLs = {
    2017: {
        "L1C": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh01.csv",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh02.csv",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh03.csv",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh04.csv",
            "belle-ile": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/belle-ile.csv"
        },
        "L2A": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh01.csv",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh02.csv",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh03.csv",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh04.csv",
            "belle-ile": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/belle-ile.csv"
        }
    },
    2018: {
            "L1C": {
                "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh01.csv",
                "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh02.csv",
                "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh03.csv",
                "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh04.csv",
            }
        }
}

SHP_URLs = {
    2017: {
        "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/shp/frh01.tar.gz",
        "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/shp/frh02.tar.gz",
        "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/shp/frh03.tar.gz",
        "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/shp/frh04.tar.gz",
        "belle-ile": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/shp/belle-ile.tar.gz"
    },
    2018: {
        "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/shp/frh01.tar.gz",
        "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/shp/frh02.tar.gz",
        "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/shp/frh03.tar.gz",
        "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/shp/frh04.tar.gz",
    }
}

FILESIZES = {
    2017: {
        "L1C": {
            "frh01": 2559635960,
            "frh02": 2253658856,
            "frh03": 2493572704,
            "frh04": 1555075632,
            "belle-ile": 17038944
        },
        "L2A": {
            "frh01": 987259904,
            "frh02": 803457960,
            "frh03": 890027448,
            "frh04": 639215848,
            "belle-ile": 8037952
        }
    },
    2018: {
        "L1C": {
            "frh01": 9878839310,
            "frh02": 8567550069,
            "frh03": 10196638286,
            "frh04": 6270634169
        }
    }
}

H5_URLs = {
    2017: {
        "L1C": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh01.h5.tar.gz",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh02.h5.tar.gz",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh03.h5.tar.gz",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh04.h5.tar.gz",
            "belle-ile": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/belle-ile.h5.tar.gz"
        },
        "L2A": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh01.h5.tar.gz",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh02.h5.tar.gz",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh03.h5.tar.gz",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh04.h5.tar.gz",
            "belle-ile": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/belle-ile.h5.tar.gz"
        }
    }
}

# 9-classes used in ISPRS submission
CLASSMAPPINGURL = "https://breizhcrops.s3.eu-central-1.amazonaws.com/classmapping.csv"

# 13-classes used in ICML workshop
CLASSMAPPINGURL_ICML = "https://breizhcrops.s3.eu-central-1.amazonaws.com/classmapping_icml.csv"

CODESURL = "https://breizhcrops.s3.eu-central-1.amazonaws.com/codes.csv"

==> breizhcrops-0.0.4.1-py3-none-any.whl: breizhcrops/datasets/urls.py <==
RAW_CSV_URL = {
    2017: {
        "L1C": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh01.zip",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh02.zip",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh03.zip",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh04.zip",
        },
        "L2A": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh01.zip",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh02.zip",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh03.zip",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh04.zip",

        }
    },
    2018: {
        "L1C": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh01.zip",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh02.zip",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh03.zip",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh04.zip",
        }
    }
}

INDEX_FILE_URLs = {
    2017: {
        "L1C": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh01.csv",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh02.csv",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh03.csv",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh04.csv",
            "belle-ile": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/belle-ile.csv",
            "kermaux": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/kermaux.csv"
        },
        "L2A": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh01.csv",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh02.csv",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh03.csv",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh04.csv",
            "belle-ile": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/belle-ile.csv"
        }
    },
    2018: {
            "L1C": {
                "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh01.csv",
                "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh02.csv",
                "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh03.csv",
                "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/L1C/frh04.csv",
            }
        }
}

SHP_URLs = {
    2017: {
        "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/shp/frh01.tar.gz",
        "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/shp/frh02.tar.gz",
        "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/shp/frh03.tar.gz",
        "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/shp/frh04.tar.gz",
        "belle-ile": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/shp/belle-ile.tar.gz",
        "kermaux": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/shp/kermaux.tar.gz"
    },
    2018: {
        "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/shp/frh01.tar.gz",
        "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/shp/frh02.tar.gz",
        "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/shp/frh03.tar.gz",
        "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2018/shp/frh04.tar.gz",
    }
}

FILESIZES = {
    2017: {
        "L1C": {
            "frh01": 2559635960,
            "frh02": 2253658856,
            "frh03": 2493572704,
            "frh04": 1555075632,
            "belle-ile": 17038944,
            "kermaux": 1259784,
        },
        "L2A": {
            "frh01": 987259904,
            "frh02": 803457960,
            "frh03": 890027448,
            "frh04": 639215848,
            "belle-ile": 8037952
        }
    },
    2018: {
        "L1C": {
            "frh01": 9878839310,
            "frh02": 8567550069,
            "frh03": 10196638286,
            "frh04": 6270634169
        }
    }
}

H5_URLs = {
    2017: {
        "L1C": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh01.h5.tar.gz",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh02.h5.tar.gz",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh03.h5.tar.gz",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/frh04.h5.tar.gz",
            "belle-ile": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/belle-ile.h5.tar.gz",
            "kermaux": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L1C/kermaux.h5.tar.gz",
        },
        "L2A": {
            "frh01": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh01.h5.tar.gz",
            "frh02": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh02.h5.tar.gz",
            "frh03": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh03.h5.tar.gz",
            "frh04": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/frh04.h5.tar.gz",
            "belle-ile": "https://breizhcrops.s3.eu-central-1.amazonaws.com/2017/L2A/belle-ile.h5.tar.gz"
        }
    }
}

# 9-classes used in ISPRS submission
CLASSMAPPINGURL = "https://breizhcrops.s3.eu-central-1.amazonaws.com/classmapping.csv"

# 13-classes used in ICML workshop
CLASSMAPPINGURL_ICML = "https://breizhcrops.s3.eu-central-1.amazonaws.com/classmapping_icml.csv"

CODESURL = "https://breizhcrops.s3.eu-central-1.amazonaws.com/codes.csv"
